*** Settings ***
Documentation     Check that you can update a batch of entities where some will succeed and others will fail
Resource          ${EXECDIR}/resources/ApiUtils.resource
Resource          ${EXECDIR}/resources/AssertionUtils.resource
Resource          ${EXECDIR}/resources/JsonUtils.resource
Suite Setup       Setup Initial Entities

*** Variable ***
${building_id_prefix}=    urn:ngsi-ld:Building:
${entity_payload_filename}=    building-simple-attributes-sample.jsonld
${update_fragment_filename}=    fragmentEntities/simple-attributes-relationship-of-property-fragment.json

*** Test Case ***
Update a batch of non existing and existing entities
    [Documentation]    Check that you can update a batch of non existing and existing entities
    [Tags]    be-update    5_6_9
    ${first_existing_entity}=    Load Entity    building-relationship-of-property-sample.jsonld    ${first_existing_entity_id}
    ${second_existing_entity}=    Load Entity    building-relationship-of-property-sample.jsonld    ${second_existing_entity_id}
    ${new_entity_id}=    Generate Random Entity Id    ${building_id_prefix}
    ${new_entity}=    Load Entity    building-relationship-of-property-sample.jsonld    ${new_entity_id}
    @{entities_to_be_updated}=    Create List    ${first_existing_entity}    ${second_existing_entity}    ${new_entity}
    Batch Update Entities    @{entities_to_be_updated}
    @{expected_successful_entities_ids}=    Create List    ${first_existing_entity_id}    ${second_existing_entity_id}
    @{expected_failed_entities_ids}=    Create List    ${new_entity_id}
    &{expected_batch_operation_result}=    Create Batch Operation Result    ${expected_successful_entities_ids}    ${expected_failed_entities_ids}
    Check Response Status Code Set To    207
    Check Response Body Containing Batch Operation Result    ${expected_batch_operation_result}
    ${first_created_entity}=    Load Test Sample    entities/${entity_payload_filename}    ${first_existing_entity_id}
    ${second_created_entity}=    Load Test Sample    entities/${entity_payload_filename}    ${second_existing_entity_id}
    ${update_fragment}=    Load Test Sample    entities/${update_fragment_filename}
    ${first_updated_entity}=    Upsert Element In Entity    ${first_created_entity}    ${update_fragment}
    ${second_updated_entity}=    Upsert Element In Entity    ${second_created_entity}    ${update_fragment}
    @{updated_entities}=    Create List    ${first_updated_entity}    ${second_updated_entity}
    ${expected_entities_ids}=    Catenate    SEPARATOR=,    @{expected_successful_entities_ids}
    Query Entities    ${expected_entities_ids}    Building    context=${ngsild_test_suite_context}    accept=${CONTENT_TYPE_LD_JSON}
    Check Updated Resources Set To    ${updated_entities}
    Batch Delete Entities    @{expected_successful_entities_ids}

*** Keywords ***
Setup Initial Entities
    ${first_existing_entity_id}=    Generate Random Entity Id    ${building_id_prefix}
    ${second_existing_entity_id}=    Generate Random Entity Id    ${building_id_prefix}
    Create Entity    ${entity_payload_filename}    ${first_existing_entity_id}
    Create Entity    ${entity_payload_filename}    ${second_existing_entity_id}
    Set Suite Variable    ${first_existing_entity_id}
    Set Suite Variable    ${second_existing_entity_id}
